@@ -1,22 +1,9 @@
 /*
   This file is part of the kcalcore library.
 
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -38,8 +25,8 @@
 
 using namespace KCalendarCore;
 
-namespace KCalendarCore {
-
+namespace KCalendarCore
+{
 class ExceptionPrivate
 {
 public:
